@@ -771,7 +771,8 @@ class MammothConnector(object):
         url = '/integrations/{0}/identities/{1}/dsConfigs'.format(integration_key, identity_key)
         r = self._make_signed_request('post', url, json=ds_config)
         data = r.json()
-        return data['is_valid']
+        # return data['is_valid']
+        return data
 
     @handleError
     def create_third_party_dataset(self, ds_param, wait_till_ready=False):
